pub struct PathSegment {
pub ident: Ident,
pub arguments: PathArguments,
}Expand description
A segment of a path together with any path arguments on that segment.
This type is available only if Syn is built with the "derive" or "full"
feature.
Fields
ident: Identarguments: PathArgumentsTrait Implementations
Sourceimpl Clone for PathSegment
Available on crate features derive or full only.
impl Clone for PathSegment
Available on crate features
derive or full only.Sourcefn clone(&self) -> PathSegment
fn clone(&self) -> PathSegment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T> From<T> for PathSegment
impl<T> From<T> for PathSegment
Sourcefn from(ident: T) -> PathSegment
fn from(ident: T) -> PathSegment
Converts to this type from the input type.
Sourceimpl Parse for PathSegment
impl Parse for PathSegment
fn parse(input: &ParseBuffer<'_>) -> Result<PathSegment, Error>
Sourceimpl ToTokens for PathSegment
impl ToTokens for PathSegment
Sourcefn to_tokens(&self, tokens: &mut TokenStream)
fn to_tokens(&self, tokens: &mut TokenStream)
Sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
Sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere
Self: Sized,